@@ -92,8 +92,10 @@ def before_request_auth():
     if auth_type in ['x509_proxy']:
         dn = flask.request.environ.get('SSL_CLIENT_S_DN', None)
         client_cert = flask.request.environ.get('SSL_CLIENT_CERT', None)
-        dn = dn.strip()
-        client_cert = client_cert.strip()
+        if dn:
+            dn = dn.strip()
+        if client_cert:
+            client_cert = client_cert.strip()
         if not dn or len(dn) == 0:
             dn = flask.request.headers.get('SSL-CLIENT-S-DN', default=None)
         if not client_cert or len(client_cert) == 0:
